match_delim

Function match_delim 

pub fn match_delim(s: &str, open: usize) -> Option<usize>
Byte index of the delimiter matching the one at open, or None when the source is unbalanced.

open must be a byte index of an opening delimiter in s. Nested delimiters and string literals (", ', backtick) are skipped.