fn skip_string(it: &mut CharIndices<'_>, quote: char)Expand description
Consumes an iterator up to and including the closing quote.
fn skip_string(it: &mut CharIndices<'_>, quote: char)Consumes an iterator up to and including the closing quote.