stage_licences

Function stage_licences 

fn stage_licences() -> Result<()>
release-web embeds DejaVuSans via include_bytes!, and that font’s licence requires its notice to travel with copies of the font software. web/static is copied wholesale into the runtime image, so putting it here makes it ship with both the tarball and the image, and be servable.