pub fn read_rate(path: &Path, bytes: u64, threads: usize) -> Result<Value>
Read bytes from path past the page cache with threads parallel readers at spread offsets, and report the achieved rate in decimal GB/s.
bytes
path
threads